<?php
/**
 * @file
 * Blockpop instance controller file.
 */

/**
 * Blockpop instance controller class.
 */
class BlockPopInstanceController extends EntityAPIController {
  /**
   * {@inheritdoc}
   */
  function load($ids = array(), $conditions = array()) {
    $instances = parent::load($ids, $conditions);
    $default_settings = _blockpop_get_settings_default_values();

    foreach ($instances as $id => $instance) {
      if (!array_key_exists('ga_event_label', $instance->settings)) {
        $instance->settings['ga_event_label'] = $instance->title;
      }

      // Use default values for missing settings.
      $instances[$id]->settings += $default_settings;
    }

    return $instances;
  }

  /**
   * {@inheritdoc}
   */
  function save($instance, DatabaseTransaction $transaction = NULL) {
    if (empty($instance->settings['timestamp'])) {
      // Init (or reset) cookie setup time.
      $instance->settings['timestamp'] = REQUEST_TIME;
    }

    foreach (array('start_date', 'end_date') as $date_type) {
      if (empty($instance->settings[$date_type . '_enable'])) {
        // If start/end date is not enabled, leave the date unset so the
        // suggested date on config form is always based on user's current time.
        unset($instance->settings[$date_type]);
        unset($instance->settings[$date_type . '_tz']);
      }
    }

    $return = parent::save($instance, $transaction);
    cache_clear_all(NULL, 'cache_block');
    return $return;
  }

  /**
   * {@inheritdoc}
   */
  function delete($ids, DatabaseTransaction $transaction = NULL) {
    parent::delete($ids, $transaction);
    cache_clear_all(NULL, 'cache_block');
  }
}
