<?php
/**
 * @file
 * File for Blockpop instance entity hooks and functions.
 */

require_once 'BlockPopInstanceController.inc';
require_once 'BlockPopInstanceUIController.inc';

/**
 * Implements hook_entity_info().
 */
function blockpop_entity_info() {
  return array(
    'blockpop_instance' => array(
      'label' => t('Blockpop instance'),
      'label plural' => t('Blockpop instances'),
      'base table' => 'blockpop_instance',
      'controller class' => 'BlockPopInstanceController',
      'access callback' => 'blockpop_instance_access',
      'module' => 'blockpop',
      'entity keys' => array(
        'id' => 'id',
        'label' => 'title',
      ),
      'admin ui' => array(
        'path' => 'admin/config/user-interface/blockpop-instances',
        'controller class' => 'BlockPopInstanceUIController',
      ),
    ),
  );
}

/**
 * Access callback for a Blockpop instance.
 */
function blockpop_instance_access($op, $profile = NULL, $account = NULL) {
  return user_access('administer blocks', $account);
}

/**
 * Loads Blockpop instance by block delta.
 */
function blockpop_instance_load_by_delta($delta, $reset = FALSE) {
  $parts = explode('_', $delta);
  if (count($parts) != 2 || $parts[0] != 'popup') {
    return FALSE;
  }

  $instances = entity_load('blockpop_instance', array($parts[1]));
  if (empty($instances)) {
    return FALSE;
  }

  return reset($instances);
}

/**
 * Builds Blockpop instance form.
 */
function blockpop_instance_form($form, &$form_state, $instance, $op = 'edit', $entity_type = NULL) {
  $form['title'] = array(
    '#title' => t('Title'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => isset($instance->title) ? $instance->title : '',
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  if ($op == 'edit') {
    $path = 'admin/structure/block/manage/blockpop/popup_' . $instance->id . '/configure';
    $form['actions']['block_link'] = array(
      '#markup' => l(t('Configure block'), $path),
    );
  }

  return $form;
}

/**
 * Submit callback for the Blockpop instance form.
 */
function blockpop_instance_form_submit(&$form, &$form_state) {
  $instance = entity_ui_form_submit_build_entity($form, $form_state);
  entity_save('blockpop_instance', $instance);
  $form_state['redirect'] = 'admin/config/user-interface/blockpop-instances';
  drupal_set_message(t('The Blockpop instance has been saved.'));
}
