/*
 * Pop that popup up on the page.
 */
(function ($, Drupal, window, document, undefined) {

  Drupal.behaviors.blockPopPopup = {
    attach: function(context, settings) {
      if (typeof settings.blockpop === 'undefined') {
        return;
      }
      var self = this;
      self.popups = settings.blockpop;
      $.each(settings.blockpop, function(delta, popupSettings) {
        var $popup = $('#block-blockpop-' + delta.replace('_', '-'), context);
        if ($popup.length === 0) {
          return;
        }
        $popup.once('blockpop-popup', function() {
          $popup.data('block_delta', delta);
          if (self.shouldShowPopup($popup)) {
            setTimeout(function($popup) {
              self.initAndTriggerPopup($popup);
            }, popupSettings.timeDelayInSeconds * 1000, $popup);
          }
        });
      });
    },
    popups: null,
    initAndTriggerPopup: function($popup) {
      var self = this;
      var delta = $popup.data('block_delta');
      var settings = self.popups[delta];
      $popup.addClass('modal')
        .css('border-radius', settings.borderRadius + 'px')
        .css('padding', settings.padding + 'px');
      if (!!settings.popupStyle) {
        $popup.addClass(settings.popupStyle);
      }
      $popup.modal({closeExisting: false});
      $popup.parent().css('z-index', settings.zIndex);
      self.resizePopup($popup);
      $popup.find('.content a').click(function(event) {
        self.clickHandler(event);
      });

      var expirationHours = parseInt(settings.cookieExpirationHours);
      var now = new Date();
      var expirationDate = new Date(now.getTime() + (expirationHours * 60 * 60 * 1000));
      $.cookie('blockpop_' + delta + '_last_shown', settings.timestamp, {
        expires: expirationDate
      });
      $popup.find('img').load(function() {
        self.resizePopup($popup);
      });
      $(window).load(function() {
        self.resizePopup($popup);
      }).resize(function() {
        self.resizePopup($popup);
      });
      $popup.trigger('blockpop:load');
    },
    resizePopup: function($popup) {
      var delta = $popup.data('block_delta');
      var settings = this.popups[delta];
      //document.body.clientWidth is width without scrollbar
      if (document.body.clientWidth < parseInt(settings.width) + 2 * parseInt(settings.padding)) {
        var width = document.body.clientWidth - 20 - parseInt(settings.padding);
      }
      else {
        var width = parseInt(settings.width);
      }
      $popup.css('max-width', width);
    },
    shouldShowPopup: function($popup) {
      var delta = $popup.data('block_delta');
      var settings = this.popups[delta];
      var lastShown = $.cookie('blockpop_' + delta + '_last_shown');
      var show = true;
      var now = new Date().getTime();
      now = Math.round(now / 1000);
      var start = new Date();
      start.setTime(settings.startDateUtc * 1000);
      if (!!settings.startDateUtc && now < settings.startDateUtc) {
        show = false;
      }
      if (!!settings.endDateUtc && now > settings.endDateUtc) {
        show = false;
      }
      if (lastShown == settings.timestamp && settings.cookieExpiration !== 'always') {
        show = false;
      }
      return show;
    },
    clickHandler: function(event) {
      var $link = $(event.target).closest('.blockpop-popup-processed a');
      if ($link.length === 0) {
        return;
      }
      $link.trigger('blockpop:click', [event]);
      if (!window._gaq && !window.ga) {
        return;
      }
      var href = $link.attr('href');
      if (typeof href === 'undefined' || !href) {
        return;
      }
      var $popup = $link.closest('.blockpop-popup-processed');
      var delta = $popup.data('block_delta');
      var gaEventCategory = this.popups[delta].gaEventCategory ? this.popups[delta].gaEventCategory : null;
      var gaEventAction = this.popups[delta].gaEventAction ? this.popups[delta].gaEventAction : null;
      if ($link.data('gaEventCategory') && $link.data('gaEventAction')) {
        gaEventCategory = $link.data('gaEventCategory');
        gaEventAction = $link.data('gaEventAction');
      }
      if (!gaEventCategory || !gaEventAction) {
        return;
      }
      var gaParams = [gaEventCategory, gaEventAction];
      var gaEventLabel = this.popups[delta].gaEventLabel ? this.popups[delta].gaEventLabel : null;
      if ($link.data('gaEventLabel')) {
        gaEventLabel = $link.data('gaEventLabel');
      }
      if (!!gaEventLabel) {
        gaParams.push(gaEventLabel);
      }
      event.preventDefault();
      this.gaEvent(gaParams, $link.attr('href'));
    },
    gaEvent: function(params, href) {
      if (typeof _gaq === 'object') {
        // Classic Analytics ga.js.
        _gaq.push(['_set', 'hitCallback', function() {
          document.location = href;
        }]);
        params.splice(0, 0, '_trackEvent');
        _gaq.push(params);
      }
      else if (typeof ga === 'function') {
        // Universal Analytics analytics.js.
        params.push({
          useBeacon: true,
          hitCallback: function() {
            document.location = href;
          }
        });
        params.splice(0, 0, 'send', 'event');
        ga.apply(this, params);
      }
    }
  };
})(jQuery, Drupal, this, this.document);
